<?php

namespace Modules\Cadastros\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO\Response\Notification;
use Modules\Cadastros\Services\gql00100DestinoDoProdutoService;
use Zeedhi\Framework\DTO\Response\Message;

class gql00100DestinoDoProdutoController extends \Zeedhi\Framework\Controller\Report
{
    protected $connection;
    protected $qr2Strategy;

    public function __construct(
        reportService $reportService,
        gql00100DestinoDoProdutoService $service,
        $connection,
        $qr2Strategy
    ) {
        parent::__construct($reportService);
        $this->connection    = $connection;
        $this->service       = $service;
        $this->qr2Strategy   = $qr2Strategy;
    }

    public function insertDestinoDoProduto(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();

            $codDestProd = $this->service->getCodDestProd($row);
            if ($codDestProd) {
                throw new \Exception("CODIGO_CADASTRADO");
            }

            $descricao = $this->service->getDescricao($row);
            if ($descricao) {
                throw new \Exception("DESC_CADASTRADA");
            }

            if ((empty($codDestProd)) and (empty($descricao))) {
                $this->service->insertDestinoDoProduto($row);
            }
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function confirmarEditDestinoDoProduto(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();

            $descricao = $this->service->getDescricao($row);
            if ($descricao) {
                throw new \Exception("DESC_CADASTRADA");
            }

            $this->service->updateDestinoDoProduto($row);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function deleteDestinoDoProduto(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();

            $this->service->deleteDestinoDoProduto($row);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
}
